Telescope Workflows
=======================
A telescope a type of workflow used to ingest data from different data sources, and to run workflows that process and
output data to other places. Workflows are built on top of Apache Airflow's DAGs.

.. toctree::
    :maxdepth: 1

    doab
    google_analytics
    google_books
    jstor
    oapen_metadata
    oapen_irus_uk
    ucl_discovery
